Welcome to AIND Behavior Experiment Launcher's documentation!
=================================================================

.. mdinclude:: ../README.md


.. autosummary::

   :toctree: _autosummary
   :caption: API
   :template: custom-module-template.rst
   :recursive:


   aind_behavior_experiment_launcher


.. toctree::
   :maxdepth: 4
   :caption: Contents:

   self
   _autosummary/aind_behavior_experiment_launcher
   articles
   GitHub Source Code <https://github.com/AllenNeuralDynamics/Aind.Behavior.ExperimentLauncher>





Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
